from hurry.resource import Library, ResourceInclusion

jqueryui_themes = Library('jqueryui_themes', 'jqueryui-themes')

cupertino = ResourceInclusion(jqueryui_themes, 'cupertino/jquery-ui.css')
flick = ResourceInclusion(jqueryui_themes, 'flick/jquery-ui.css')
pepper_grinder = ResourceInclusion(jqueryui_themes, 'pepper-grinder/jquery-ui.css')
mint_choc = ResourceInclusion(jqueryui_themes, 'mint-choc/jquery-ui.css')
vader = ResourceInclusion(jqueryui_themes, 'vader/jquery-ui.css')
swanky_purse = ResourceInclusion(jqueryui_themes, 'swanky-purse/jquery-ui.css')
ui_darkness = ResourceInclusion(jqueryui_themes, 'ui-darkness/jquery-ui.css')
start = ResourceInclusion(jqueryui_themes, 'start/jquery-ui.css')
dot_luv = ResourceInclusion(jqueryui_themes, 'dot-luv/jquery-ui.css')
south_street = ResourceInclusion(jqueryui_themes, 'south-street/jquery-ui.css')
excite_bike = ResourceInclusion(jqueryui_themes, 'excite-bike/jquery-ui.css')
dark_hive = ResourceInclusion(jqueryui_themes, 'dark-hive/jquery-ui.css')
humanity = ResourceInclusion(jqueryui_themes, 'humanity/jquery-ui.css')
trontastic = ResourceInclusion(jqueryui_themes, 'trontastic/jquery-ui.css')
redmond = ResourceInclusion(jqueryui_themes, 'redmond/jquery-ui.css')
le_frog = ResourceInclusion(jqueryui_themes, 'le-frog/jquery-ui.css')
sunny = ResourceInclusion(jqueryui_themes, 'sunny/jquery-ui.css')
blitzer = ResourceInclusion(jqueryui_themes, 'blitzer/jquery-ui.css')
base = ResourceInclusion(jqueryui_themes, 'base/jquery-ui.css')
hot_sneaks = ResourceInclusion(jqueryui_themes, 'hot-sneaks/jquery-ui.css')
black_tie = ResourceInclusion(jqueryui_themes, 'black-tie/jquery-ui.css')
overcast = ResourceInclusion(jqueryui_themes, 'overcast/jquery-ui.css')
ui_lightness = ResourceInclusion(jqueryui_themes, 'ui-lightness/jquery-ui.css')
eggplant = ResourceInclusion(jqueryui_themes, 'eggplant/jquery-ui.css')
smoothness = ResourceInclusion(jqueryui_themes, 'smoothness/jquery-ui.css')